@@ -1,6 +1,6 @@
 /*********************************************************************/
 // libthreadar - is a library providing several C++ classes to work with threads
-// Copyright (C) 2014-2024 Denis Corbin
+// Copyright (C) 2014-2025 Denis Corbin
 //
 // This file is part of libthreadar
 //
@@ -53,7 +53,7 @@ namespace libthreadar
     mutex::~mutex()
     {
 	try_lock();
-	unlock();
+	unlock();  // we possibly unlock the mutex locked from another thread
 	(void)pthread_mutex_destroy(&mut);
     }
 
